ui

package
v0.1.22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: AGPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Spinner

type Spinner struct {
	Suffix string // Public field to match briandowns/spinner API
	// contains filtered or unexported fields
}

Spinner wraps the Bubble Tea spinner to provide a simple API similar to briandowns/spinner

func New

func New() *Spinner

New creates a new spinner with a dots style

func (*Spinner) Active

func (s *Spinner) Active() bool

Active returns whether the spinner is currently running

func (*Spinner) Restart

func (s *Spinner) Restart()

Restart stops and starts the spinner

func (*Spinner) SetSuffix

func (s *Spinner) SetSuffix(suffix string)

SetSuffix sets the text that appears after the spinner

func (*Spinner) Start

func (s *Spinner) Start()

Start begins the spinner animation

func (*Spinner) Stop

func (s *Spinner) Stop()

Stop stops the spinner animation

Jump to